@@ -50,6 +50,29 @@ class Event(object):
         """
         self.type = etype
 
+def _eventFromFrame(frame, name):
+    """
+    Automatically creates an event from the given inspect.Frame object and name.
+    It uses the following format:  <file>:<line> <EVENT>
+
+    @note All spaces in the string will be replace with '_'
+
+    @rtype : tuple
+    @return: (eventName, filteredName)
+    """
+
+    line = frame.f_lineno
+    fileName = frame.f_code.co_filename
+
+    # Make .py vs .pyc files have the same event names
+    if fileName.endswith('.pyc'):
+        fileName = fileName[:-3] + '.py'
+
+    filteredName = name.replace(' ', '_')
+    eventName = '%s:%d %s' % (fileName, line, filteredName)
+
+    return (eventName, filteredName)
+
 def declareEventType(name):
     """
     Defines an event type in a manner which will avoid collisions
@@ -64,9 +87,32 @@ def declareEventType(name):
     stack = inspect.stack()
     try:
         frame = stack[1][0]
-        line = frame.f_lineno
-        fileName = frame.f_code.co_filename
-        return '%s:%d %s' % (fileName, line, name.replace(' ', '_'))
+
+        eventName, _ = _eventFromFrame(frame, name)
+
+        return eventName
+
+    finally:
+        del stack
+
+def makeEvents(*names):
+    """
+    Defines events just like declareEventType, but sets the value in the
+    callers namespace directly.  Removing the need to assign to anything.
+    Defines an event type in a manner which will avoid collosions, in the
+    callers local namespace.
+
+    @rtype : str
+    @return: None
+    """
+
+    stack = inspect.stack()
+    try:
+        frame = stack[1][0]
+
+        for name in names:
+            eventName, filteredName = _eventFromFrame(frame, name)
+            frame.f_locals[filteredName] = eventName
     finally:
         del stack
 
@@ -89,12 +135,13 @@ class State(object):
         """
         return {}
 
-    @staticmethod
-    def getattr():
-        """
-        Returns the possible config values of the state
-        """
-        return set([])
+    # TODO: Config functionality not yet ported
+#    @staticmethod
+#    def getattr():
+#        """
+#        Returns the possible config values of the state
+#        """
+#        return set([])
 
     def enter(self):
         """
@@ -124,7 +171,9 @@ class End(State):
     intended to be that way.
     """
     def __init__(self, config = None, **kwargs):
-        State.__init__(self, config, **kwargs)
+        # TODO: config functionality not yet ported
+        #State.__init__(self, config, **kwargs)
+        State.__init__(self, **kwargs)
 
 class Branch(object):
     """
