@@ -31,6 +31,7 @@
 import unittest
 import StringIO
 import inspect
+import os.path
 
 # Project Imports
 import statepy.state as state
@@ -51,7 +52,10 @@ class Reciever(object):
         self.called = True
 
 class MockEventSource(object):
-    THING_UPDATED = state.declareEventType('THING_UPDATED')
+    # Test the magic event syntax
+    state.makeEvents('THING_UPDATED', 'MULTI EVENT')
+
+    # Test the normal event syntax
     ANOTHER_EVT = state.declareEventType('ANOTHER_EVT')
 
 class TrackedState(state.State):
@@ -188,7 +192,8 @@ class TestFreeFunctions(unittest.TestCase):
 
     
     def testDeclareEventType(self):
-        fileName = __file__
+        # Make sure the path always ends in .py
+        fileName = os.path.splitext(__file__)[0] + ".py"
         expectedLineNum = str(self.lineno() + 1)
         evtType = state.declareEventType("An Event")
 
@@ -309,6 +314,9 @@ class TestStateMachine(unittest.TestCase):
 #        self.assertEquals(endName, enterRecv.event.string)
 #        self.assertEquals(endName, exitRecv.event.string)
 
+
+# NOTE: No event system in stand alone StatePy so these sections are disabled
+
 #    def testEvents(self):
 #        enterRecv = Reciever()
 #        exitRecv = Reciever()
@@ -370,6 +378,10 @@ class TestStateMachine(unittest.TestCase):
         self.assertNotEquals(None, startState.thingUpdatedEvent)
         self.assertEquals(startState.thingUpdatedEvent.value, 4)
 
+    def testMakeEvents(self):
+        self.assertTrue(hasattr(MockEventSource, 'THING_UPDATED'))
+        self.assertTrue(hasattr(MockEventSource, 'MULTI_EVENT'))
+
     def testStatevars(self):
         vara = "A"
         varB = 10
@@ -541,6 +553,21 @@ class TestState(unittest.TestCase):
         s = state.State(a = 5, bob = 'A')
         self.assertEqual(5, s.a)
         self.assertEqual('A', s.bob)
+
+# --------------------------------------------------------------------------- #
+#                             T E S T    E N D                                #
+# --------------------------------------------------------------------------- #
+
+class TestEndEnd(state.End):
+    """End test state"""
+    def __init__(self):
+        state.End.__init__(self)
+                
+# Testing of End Class
+class TestEnd(unittest.TestCase):
+    def testinit(self):
+        a = TestEndEnd()
+
                 
 if __name__ == '__main__':
     unittest.main()
